@@ -19,10 +19,6 @@ import os
 # the /etc/hosts file, causing problems for for installs.
 os.environ['EVENTLET_NO_GREENDNS'] = 'yes'
 
-import eventlet
-
-eventlet.monkey_patch()
-
 import socket
 
 from oslo_config import cfg
@@ -31,7 +27,7 @@ from oslo_concurrency import lockutils
 import oslo_messaging as messaging
 
 
-cfg.CONF.register_opts([
+designate_opts = [
     cfg.StrOpt('host', default=socket.gethostname(),
                help='Name of this node'),
     cfg.StrOpt(
@@ -50,21 +46,23 @@ cfg.CONF.register_opts([
     cfg.StrOpt('worker-topic', default='worker', help='Worker Topic'),
 
     # Default TTL
-    cfg.IntOpt('default-ttl', default=3600),
+    cfg.IntOpt('default-ttl', default=3600, help='TTL Value'),
 
     # Default SOA Values
     cfg.IntOpt('default-soa-refresh-min', default=3500,
-               deprecated_name='default-soa-refresh'),
-    cfg.IntOpt('default-soa-refresh-max', default=3600),
-    cfg.IntOpt('default-soa-retry', default=600),
-    cfg.IntOpt('default-soa-expire', default=86400),
-    cfg.IntOpt('default-soa-minimum', default=3600),
+               deprecated_name='default-soa-refresh',
+               help='SOA refresh-min value'),
+    cfg.IntOpt('default-soa-refresh-max', default=3600,
+               help='SOA max value'),
+    cfg.IntOpt('default-soa-retry', default=600, help='SOA retry'),
+    cfg.IntOpt('default-soa-expire', default=86400, help='SOA expire'),
+    cfg.IntOpt('default-soa-minimum', default=3600, help='SOA minimum value'),
 
     # Supported record types
     cfg.ListOpt('supported-record-type', help='Supported record types',
                 default=['A', 'AAAA', 'CNAME', 'MX', 'SRV', 'TXT', 'SPF', 'NS',
                          'PTR', 'SSHFP', 'SOA']),
-])
+]
 
 # Set some Oslo Log defaults
 log.set_defaults(default_log_levels=[
@@ -77,6 +75,7 @@ log.set_defaults(default_log_levels=[
     'keystone=INFO',
     'keystonemiddleware.auth_token=INFO',
     'oslo_messaging=WARN',
+    'oslo.messaging=INFO',
     'oslo_service.loopingcall=WARN',
     'sqlalchemy=WARN',
     'stevedore=WARN',
@@ -88,3 +87,5 @@ messaging.set_transport_defaults('designate')
 
 # Set some Oslo Oslo Concurrency defaults
 lockutils.set_defaults(lock_path='$state_path')
+
+cfg.CONF.register_opts(designate_opts)
