@@ -5,7 +5,7 @@ XTRACE=$(set +o | grep xtrace)
 set +o xtrace
 
 # Get backend configuration
-# ----------------------------
+# -------------------------
 if is_service_enabled designate && [[ -r $DESIGNATE_PLUGINS/backend-$DESIGNATE_BACKEND_DRIVER ]]; then
     # Load plugin
     source $DESIGNATE_PLUGINS/backend-$DESIGNATE_BACKEND_DRIVER
@@ -52,7 +52,6 @@ function configure_designate {
     iniset $DESIGNATE_CONF DEFAULT rpc_response_timeout 5
 
     iniset $DESIGNATE_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
-    iniset $DESIGNATE_CONF DEFAULT verbose True
     iniset $DESIGNATE_CONF DEFAULT state_path $DESIGNATE_STATE_PATH
     iniset $DESIGNATE_CONF DEFAULT root-helper sudo designate-rootwrap $DESIGNATE_ROOTWRAP_CONF
     iniset $DESIGNATE_CONF storage:sqlalchemy connection `database_connection_url designate`
@@ -89,15 +88,21 @@ function configure_designate {
     iniset $DESIGNATE_CONF service:api enabled_extensions_v1 $DESIGNATE_ENABLED_EXTENSIONS_V1
     iniset $DESIGNATE_CONF service:api enabled_extensions_v2 $DESIGNATE_ENABLED_EXTENSIONS_V2
     iniset $DESIGNATE_CONF service:api enabled_extensions_admin $DESIGNATE_ENABLED_EXTENSIONS_ADMIN
-    iniset $DESIGNATE_CONF service:api api_host $DESIGNATE_SERVICE_HOST
     iniset $DESIGNATE_CONF service:api api_base_uri $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/
     iniset $DESIGNATE_CONF service:api enable_api_v1 $DESIGNATE_ENABLE_API_V1
     iniset $DESIGNATE_CONF service:api enable_api_v2 $DESIGNATE_ENABLE_API_V2
     iniset $DESIGNATE_CONF service:api enable_api_admin $DESIGNATE_ENABLE_API_ADMIN
 
     # mDNS Configuration
-    iniset $DESIGNATE_CONF service:mdns host $DESIGNATE_SERVICE_HOST
-    iniset $DESIGNATE_CONF service:mdns port $DESIGNATE_SERVICE_PORT_MDNS
+    iniset $DESIGNATE_CONF service:mdns listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_MDNS}
+
+    # Worker Configuration
+    if is_service_enabled designate-worker; then
+        iniset $DESIGNATE_CONF service:worker enabled True
+        iniset $DESIGNATE_CONF service:worker notify True
+        iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
+        iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
+    fi
 
     # Set up Notifications/Ceilometer Integration
     iniset $DESIGNATE_CONF DEFAULT notification_driver "$DESIGNATE_NOTIFICATION_DRIVER"
@@ -121,13 +126,13 @@ function configure_designate {
     # TLS Proxy Configuration
     if is_service_enabled tls-proxy; then
         # Set the service port for a proxy to take the original
-        iniset $DESIGNATE_CONF service:api api_port $DESIGNATE_SERVICE_PORT_INT
+        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_INT}
     else
-        iniset $DESIGNATE_CONF service:api api_port $DESIGNATE_SERVICE_PORT
+        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT}
     fi
 
     # Setup the Keystone Integration
-    if is_service_enabled key; then
+    if is_service_enabled keystone; then
         iniset $DESIGNATE_CONF service:api auth_strategy keystone
         configure_auth_token_middleware $DESIGNATE_CONF designate $DESIGNATE_AUTH_CACHE_DIR
     fi
@@ -163,9 +168,13 @@ function configure_designate_tempest() {
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v1 $DESIGNATE_ENABLE_API_V1
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v2 $DESIGNATE_ENABLE_API_V2
         iniset $TEMPEST_CONFIG dns_feature_enabled api_admin $DESIGNATE_ENABLE_API_ADMIN
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_root_recordsets True
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_quotas True
+        iniset $TEMPEST_CONFIG dns_feature_enabled bug_1573141_fixed True
 
         # Tell tempest where are nameservers are.
         nameservers=$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT_DNS
+        # TODO(kiall): Remove hardcoded list of plugins
         case $DESIGNATE_BACKEND_DRIVER in
             bind9|powerdns)
                 nameservers="$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT_DNS"
@@ -198,14 +207,12 @@ function create_designate_accounts {
     if is_service_enabled designate-api; then
         create_service_user "designate"
 
-        if [[ "$KEYSTONE_CATALOG_BACKEND" = 'sql' ]]; then
-            get_or_create_service "designate" "dns" "Designate DNS Service"
-            get_or_create_endpoint "dns" \
-                "$REGION_NAME" \
-                "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
-                "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
-                "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/"
-        fi
+        get_or_create_service "designate" "dns" "Designate DNS Service"
+        get_or_create_endpoint "dns" \
+            "$REGION_NAME" \
+            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
+            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
+            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/"
     fi
 }
 
@@ -250,11 +257,11 @@ function init_designate {
 
 # install_designate - Collect source and prepare
 function install_designate {
-    install_package libcap2-bin
-
-    if is_fedora; then
-        # This package provides `dig`
-        install_package bind-utils
+    if is_ubuntu; then
+        install_package libcap2-bin
+    elif is_fedora; then
+        # bind-utils package provides `dig`
+        install_package libcap bind-utils
     fi
 
     git_clone $DESIGNATE_REPO $DESIGNATE_DIR $DESIGNATE_BRANCH
@@ -275,8 +282,9 @@ function install_designateclient {
 
 # install_designatedashboard - Collect source and prepare
 function install_designatedashboard {
-    git_clone $DESIGNATEDASHBOARD_REPO $DESIGNATEDASHBOARD_DIR $DESIGNATEDASHBOARD_BRANCH
-    setup_develop $DESIGNATEDASHBOARD_DIR
+    git_clone_by_name "designate-dashboard"
+    setup_dev_lib "designate-dashboard"
+
     ln -fs $DESIGNATEDASHBOARD_DIR/designatedashboard/enabled/_1710_project_dns_panel_group.py $HORIZON_DIR/openstack_dashboard/local/enabled/_1710_project_dns_panel_group.py
     ln -fs $DESIGNATEDASHBOARD_DIR/designatedashboard/enabled/_1720_project_dns_panel.py $HORIZON_DIR/openstack_dashboard/local/enabled/_1720_project_dns_panel.py
 }
@@ -298,6 +306,9 @@ function start_designate {
     run_process designate-mdns "$DESIGNATE_BIN_DIR/designate-mdns --config-file $DESIGNATE_CONF"
     run_process designate-agent "$DESIGNATE_BIN_DIR/designate-agent --config-file $DESIGNATE_CONF"
     run_process designate-sink "$DESIGNATE_BIN_DIR/designate-sink --config-file $DESIGNATE_CONF"
+    run_process designate-worker "$DESIGNATE_BIN_DIR/designate-worker --config-file $DESIGNATE_CONF"
+    run_process designate-producer "$DESIGNATE_BIN_DIR/designate-producer --config-file $DESIGNATE_CONF"
+
 
     # Start proxies if enabled
     if is_service_enabled designate-api && is_service_enabled tls-proxy; then
@@ -319,12 +330,19 @@ function stop_designate {
     stop_process designate-mdns
     stop_process designate-agent
     stop_process designate-sink
+    stop_process designate-worker
+    stop_process designate-producer
 
     stop_designate_backend
 }
 
 # This is the main for plugin.sh
 if is_service_enabled designate; then
+    # Sanify check for agent backend
+    # ------------------------------
+    if ! is_service_enabled designate-agent && [ "$DESIGNATE_BACKEND_DRIVER" == "agent" ]; then
+        die $LINENO "To use the agent backend, you must enable the designate-agent service"
+    fi
 
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Designate client"
@@ -346,9 +364,12 @@ if is_service_enabled designate; then
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         echo_summary "Configuring Designate"
         configure_designate
-        configure_designatedashboard
+        if is_service_enabled horizon; then
+            echo_summary "Configuring Designate dashboard"
+            configure_designatedashboard
+        fi
 
-        if is_service_enabled key; then
+        if is_service_enabled keystone; then
             echo_summary "Creating Designate Keystone accounts"
             create_designate_accounts
         fi
@@ -357,14 +378,14 @@ if is_service_enabled designate; then
         echo_summary "Initializing Designate"
         init_designate
 
-        echo_summary "Configuring Tempest options for Designate"
-        configure_designate_tempest
-
         echo_summary "Starting Designate"
         start_designate
 
         echo_summary "Creating Pool Configuration"
         create_designate_pool_configuration
+    elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
+        echo_summary "Configuring Tempest options for Designate"
+        configure_designate_tempest
     fi
 
     if [[ "$1" == "unstack" ]]; then
